@@ -233,3 +233,72 @@ sub DESTROY
 
 1;# return true:
 
+=pod
+
+=head1 NAME
+
+ASP4::UserAgent - Execute ASP4 requests without a web server.
+
+=head1 SYNOPSIS
+
+B<NOTE:> 99.99% of the time you will access this via L<ASP4::API>.
+
+  my HTTP::Response $res = $api->ua->get('/index.asp?foo=bar');
+  
+  my $res = $api->ua->post('/handlers/user.login', [
+    username  => 'willy',
+    password  => 'wonka',
+  ]);
+  
+  my $res = $api->ua->upload('/handlers/file.upload', [
+    foo   => 'bar',
+    baz   => 'bux',
+    file  => ['/home/john/avatar.jpg']
+  ]);
+  
+  # Some form testing:
+  my ($form) = HTML::Form->parse( $res->content, '/' );
+  $form->find_input('username')->value('bob');
+  my $res = $api->ua->submit_form( $form );
+  
+  # Add/remove a cookie:
+  $api->ua->add_cookie( "the-boss" => "me" );
+  $api->remove_cookie( "the-boss" );
+
+=head1 DESCRIPTION
+
+Enables unit-testing ASP4 applications by providing the ability to execuite web 
+pages from your code, without a webserver.
+
+=head1 PUBLIC METHODS
+
+=head2 get( $url )
+
+Calls C<$url> and returns the L<HTTP::Response> result.
+
+=head2 post( $url, $args )
+
+Calls C<$url> with C<$args> and returns the L<HTTP::Response> result.
+
+=head2 upload( $url, $args )
+
+Calls C<$url> with C<$args> and returns the L<HTTP::Response> result.
+
+=head2 submit_form( HTML::Form $form )
+
+Submits the C<$form> and returns the L<HTTP::Response> result.
+
+=head2 add_cookie( $name, $value )
+
+Adds the cookie to all subsequent requests.
+
+=head2 remove_cookie( $name )
+
+Removes the cookie (if it exists).
+
+=head1 SEE ALSO
+
+L<HTTP::Response> and L<HTML::Form>
+
+=cut
+
